# Changelog

## 2.0.2 (28.07.2025)

* **Bugfix**: Fix CLI commands

## 2.0.1 (28.07.2025)

* **Bugfix**: Remove JupyterBook hook

## 2.0.0 (28.07.2025)

* **Breaking**: Remove JupyterBook dependency
* **Breaking**: Remove support for Python 3.9

## 1.5.1 (20.02.2025)

* **Bugfix**: Fix a bug with empty errata lists

## 1.5.0 (20.02.2025)

* **New**: Added support for errata
* **Breaking**: Support for unsupported Python versions is dropped

## 1.4.0 (30.09.2024)

* **Update**: Improved the display of activities and videos in PDFs

## 1.3.1 (20.09.2024)

* **Bugfix**: Fix a bug preventing videos from being shown fullscreen

## 1.3.0 (06.09.2024)

* **New**: Added support for videos from the OCL video site

## 1.2.0 (27.06.2024)

* **Update**: Added OU branding

## 1.1.1 (27.03.2025)

* **Update**: Add ability to specify "serve" command host and port

## 1.1.0 (26.03.2025)

* **New**: Added JupyterBook CLI extension

## 1.0.0 (31.01.2025)

* **Breaking**: Removed the OU-XML related functionality
* **New**: Added basic testing
* **New**: Added support for dark mode
* **Update**: Upgrade to sphinx-book-theme >= 1.0
* **Update**: Update styling to closer match brand guidelines

## 0.5.2 (15.08.2023)

* **New**: Add support for cross-references within documents and parts
* **Update**: Update docs - ouxml generation
* **Update**: Minor updates to tag handling (Image/legend)
* **Update**: Update copyright notice in accordance with convention check

## 0.5.1 (29.06.2023)

* **Bugfix**: Fix the OU-XML tag for multi-line code blocks

## 0.5.0 (12.06.2023)

* **New**: Add support for single-part content

## 0.4.0 (30.05.2023)

* **New**: Added a version command to the CLI
* **New**: Ensure external links open in new tabs

## 0.2.2 (18.04.2023)

* **Update**: Various accessibility improvements

## 0.2.1 (08.03.2023)

* **New**: Added sphinxcontrib-mermaid dependency
* **Update**: Updated sphinx-book-theme to >=1.0.0,<2.0.0
